##  Side Panel
Clicking on any Fact Sheet in a report opens a side panel on the right. This panel gives a quick overview of essential information about the Fact Sheet. It gives you the convenience of accessing information without switching between reports and Fact Sheets.
The displayed Fact Sheet fields in the side panel depend on the chosen view. You can edit the information within the side panel by clicking on the field you want to update.
In Landscape, Matrix, Roadmap, and Circle Map reports you can also configure which fields and relations you want to be displayed in the side panel. To configure the content of the side panel, do the following:
  1. Click on Configure Content at the top of the side panel to open Side Panel Settings.
  2. In Side Panel Settings, add desired fields and relations by clicking the '+' icon.
  3. If you want, you can rearrange the order of added fields by dragging and dropping.
  4. Click Apply to see the new fields in the side panel.
  5. If you want these fields visible even when you open the report next time, click Save from the drop-down menu located at the top right of the report.


![Configuring the side panel of the report](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274816847a4410149335b4a0b6751f67_LowRes.gif)
Configuring the side panel of the report
Your ability to configure the side panel content depends on your permissions at the report and field levels. In other words, if a user lacks permission to view or edit a specific field in the metamodel, the same restriction applies to the side panel configuration.
You can configure and see most fields and relations using the configuration panel, except base fields such as name and description, location, and multi-select fields. Also, if a field or relation is part of an inactive section in the Fact Sheet, it will not appear on the side panel.
**Note**
While Project Status is a multi-select field, it is configurable, but only the Current Project Status is displayed on the side panel.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27442e0a7a441014bb119f1cbc6a4a3c_LowRes.png)
In the side panel, you can also comment and reply to comments just as you would on the Fact Sheet. Furthermore, from the side panel, you can quickly navigate to the Fact Sheet by clicking on the Fact Sheet’s name at the top.
